@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timedelta
 
 from . import errors
 import pytest
@@ -397,7 +397,7 @@ class TestGetData:
                                   },
                                   n_rows=5)
         start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
-        end = datetime.utcnow() - datetime.timedelta(days=1, hours=int(1))
+        end = datetime.utcnow() - timedelta(days=1, hours=int(1))
         for row in data["data"]:
             assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
             assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
